package ca.ubc.cs.spl.pattern.library;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.patterns.
 *
 * Contributor(s):   
 */

/**
 * Implements the abstract memento design pattern. It defines the role of 
 * <i>Originator</i>. The <i>Memento</i> role is client-usable and as such
 * defines outside this aspect. 
 *
 * Concrete sub-aspects overwrite the two abstract methods to define how
 * <i>Memento</i>s get generated and how they are used to restore the state
 * of <i>Originator</i>s.
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 07/13/02
 * 
 */
 
public abstract aspect MementoProtocol {
	                                                                            
    /**
     * Defines the <i>Originator</i> type. Used only by pattern code
     */

	protected interface Originator {}  

    /**
     * Creates a <i>Memento</i> object for an <i>Originator</i>
     *
     * @param o the originator to create a memento for
     * @returns the memento storing the originator's state
     */
	
	public abstract Memento createMementoFor(Originator o);
		
    /**
     * Restores this originator to former state using the memento passed
     *
     * @param o the originator to restore
     * @param m the memento that stores the prior state
     */

	public abstract void setMemento(Originator o, Memento m);
}