package ca.ubc.cs.spl.pattern.library;


/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.patterns.
 *
 * Contributor(s):   
 */

import java.util.Hashtable;
 
/**
 * Implements the the abstract strategy design pattern protocol<p>
 *
 * Intent: <i>Define a family of algorithms, encapsulate each one, and make
 * them interchangeable. Strategy lets the algorithm vary independently from 
 * clients that use it.</i><p>
 *
 * Participatng objects are <code>LinearSort</code> and <i>BubbleSort</i>
 * as <i>Strategies</i>, and <code>Sorter</code> as <i>Context</i>.
 *
 * In this example, an array of 10 numbers is to be sorted. Depending on the
 * number of arguments of the call to <code>Main</code>, linear sort or 
 * bubblesort are used as sorting algorithms. 
 *
 * <p><i>This is the AspectJ version.</i><p>
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 * 
 * @see LinearSort
 * @see BubbleSort
 */

 
 
public abstract aspect StrategyProtocol {
	
    /**
     * Stores the current strategy for each context
     * 
     * @param numbers the int array to sort
     */
  	Hashtable strategyPerContext = new Hashtable();
    
    /**
     * Defines the <i>Strategy</i> role
     */

	protected interface Strategy { }

    /**
     * Defines the <i>Context</i> role
     */

    protected interface Context  { }   

    /**
     * Attaches a strategy field to each context
     */
     	
	private Strategy Context.strategy = null; 

    /**
     * Sets the strategy for a given context
     * 
     * @param c the context to set the strategy for 
     * @param s the new strategy
     */
 	public void setConcreteStrategy(Context c, Strategy s) { strategyPerContext.put(c, s); }
    
    /**
     * Returns the strategy for a given context
     * 
     * @param c the context object
     * @returns the strategy object for that context
     */
 	public Strategy getConcreteStrategy(Context c) { return (Strategy) strategyPerContext.get(c); }
}



//	abstract pointcut useStrategy(Context c);
//	abstract pointcut setStrategy(Context c, Strategy s);

//	before(Context c): useStrategy(c) {
//		c.strategy = getConcreteStrategy(c);
//	}
	
//	after(Context c, Strategy s): setStrategy(c, s) {
//		setConcreteStrategy(c, s);
//	}
// idea: have aspect define method useStrategy() ?
