package examples.builder.aspectj;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.pattern.
 *
 * Contributor(s):   
 */

/**
 * Implements the driver for the Builder design pattern example.<p> 
 *
 * Intent: <i>Separate the construction of a complex object from its 
 * representation so that the same construction process can create different 
 * representations</i><p>
 *
 * Participatng objects are <code>TextBuilder</code> and 
 * <code>StructureBuilder</code> as <i>Builder</i>s that implement the
 * <code>Builder</code> interface.<p>
 *
 * In this example, <code>Main</code> acts as the <i>Director</i> that
 * uses two different builders to build string representations of a
 * person. <code>TextBuilder</code> creates a text-like representation,
 * <code>StructureBuilder</code> a XML-like one.
 *
 * <p><i>This is the AspectJ version.</i><p>  
 *
 * The abstract class is now replaced by an interface. A concrete aspect
 * attaches instance variable and default implementation. This frees the
 * participants (<i>ConcreteBuilder</i>s) to be subclasses of something
 * else.
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 * 
 * @see Builder
 * @see TextBuilder
 * @see StructureBuilder
 */

public class Main {

    /** 
     * Builds a string representation of a person using a given builder.
     *
     * @param the builder to use.
     */

    protected static void build(Builder builder) {
        builder.processType("Person");
        builder.processAttribute("Name");
        builder.processValue("James Brick");
        builder.processAttribute("Age");
        builder.processValue("33");
        builder.processAttribute("Occupation");
        builder.processValue("Builder"); 
    }

    /**
     * Implements the driver for the Builder design pattern example.<p> 
     *
     * In this example, <code>Main</code> acts as the <i>Director</i> that
     * uses two different builders to build string representations of a
     * person. <code>TextBuilder</code> creates a text-like representation,
     * <code>StructureBuilder</code> a XML-like one.
     * 
     * @param args the command-line parameters, unused.
     *
     */

    public static void main(String[] args) {
        
        Builder builder1 = new TextBuilder();
        Builder builder2 = new StructureBuilder();
        
        build(builder1);
        build(builder2);
        
        System.out.println(builder1.getResult());
        System.out.println(builder2.getResult());
    }
}