package examples.builder.java;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.pattern.
 *
 * Contributor(s):   
 */

/**
 * Implements a <i>ConcreteBuilder</i> that builds XML descriptions
 * of complex objects consisting of type, attributes and values.
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 */

public class StructureBuilder extends Builder {

    protected String type = null;
    protected String attribute = null;

    /** 
     * Defines the <i>buildPart()</i> operation for type parts.
     *
     * @param type the type to process
     */ 

    public void processType(String newType) {
        result = "<"+newType+">\n";
        type = newType;
    }
    
    /** 
     * Defines the <i>buildPart()</i> operation for attribute parts.
     *
     * @param type the type to process
     */ 

    public void processAttribute(String newAttribute) {
        if (attribute != null) {
            result += ("</" + attribute + ">\n");
        }
        result += ("\t<" + newAttribute + ">");
        this.attribute = newAttribute;
    }
    
    /** 
     * Defines the <i>buildPart()</i> operation for value parts.
     *
     * @param type the type to process
     */ 

    public void processValue(String type) {
        result += (type);
    }
    
    /** 
     * Defines the <i>getResult()</i> operation for <i>Builder</i>s. Includes
     * a default implementation.
     *
     * @param type the type to process
     */ 

    public String getResult() {
        if (attribute != null) {
            result += ("</" + attribute + ">\n");
            attribute = null;
        }
        if (type != null) {
            result += ("</" + type + ">\n");
            type = null;
        }
        return result;
    }
}  
