package examples.flyweight.java;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.patterns.
 *
 * Contributor(s):   
 */
 
/**
 * Implements a flyweight storing a single regular character
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 * 
 * @see PrintableFlyweight
 * @see PrintableFlyweightFactory
 */

public class CharacterFlyweight implements PrintableFlyweight {

    /**
     * The character this flyweight represents
     */
     
	char c;
	

    /** 
     * Creates a new flyweight and sets it to represent a particular character
     * 
     * @param c the character to represent
     */
     
	public CharacterFlyweight(char c) {
		this.c = c;
	}
	
    /** 
     * Defines the method signature for flyweights <code>print()</code> 
     * method. Implements the necessary method from the PrintableFlyweight 
     * interface.
     *
     * @param c the character to print
     */ 
     
	public void print(boolean uppercase) {
		System.out.print(uppercase ? Character.toUpperCase(c) : c);
	}
}