package examples.interpreter.aspectj;


/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.patterns.
 *
 * Contributor(s):   
 */

/**
 * Implements negation for booleans expressions. This is a concrete boolean
 * expression
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 */

public class NotExp implements BooleanExp {

    /** 
     * the expression this expression negates
     */
     
	protected BooleanExp exp = null;
	
	/**
	 * Creates a new NOT expression negating the argument expression   
	 *
	 * @param exp the expression to negate  
	 */

	public NotExp(BooleanExp exp) {
		this.exp = exp;
	}
	
    /**
     * Evaluates this expression in the given <i>Context</i>
     *
     * @param c the context to evaluate the expression in
     * @returns the boolean value of the expression
     */

	public boolean evaluate(Context c) {
		return (! exp.evaluate(c)); 
	}
}