package examples.mediator.java;


/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.patterns.
 *
 * Contributor(s):   
 */
 
import javax.swing.*;

/** 
 * Basically a JLabel. On object of this class is be the <i>Mediator</i>. 
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 */

public class Label extends JLabel implements Mediator {
	
    /**
     * Creates a new <code>Label</code> object with the provided string.
     *
     * @param s the tag for the new <code>Label</code> object 
     */
    
	public Label(String s) {
		super(s);
	}

    /**
     * Implements the appropriate interface for Mediator to set label and
     * button texts according to the experimental setup.
     *
     * @param colleague the colleague that caused the notification 
     */
    
	public void colleagueChanged(Colleague colleague) { 
	    Button button = (Button) colleague;
	    
		if (button == Main.button1) {
			this.setText("Button1 clicked"); 
		} else if (button == Main.button2) {
			this.setText("Button2 clicked");
		}
		button.setText("(Done)");
	}
}