package examples.mediator.java;


/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.patterns.
 *
 * Contributor(s):   
 */

/**
 * Implements the driver for the mediator design pattern example.<p> 
 *
 * Intent: <i>Define an object that encapsulates how a set of objects
 * interact. Mediator promotes loose coupling by keeping objects from 
 * referring to each other explicitly, and it lets you vary their interaction
 * independently.</i><p>
 *
 * Participatng objects are <code>Button</code>s as <i>Colleague</i>s,
 * and a <code>Label</code> as <i>Mediator</i>.
 *
 * Every time an event of interest (a button click) occurs, the mediating
 * <code>Label</code> is updated and it updates the calling button.
 *
 * <p><i>This is the Java version.</i><p>    
 *
 * Both <i>Mediator</i> and <i>Colleagues</i> have to be aware of their role
 * within the pattern.
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 * 
 */
 
public interface Mediator {
    
    /**
     * Defines the method signature for notifying mediators of changes to
     * colleagues. This method is called by colleagues who pass themselves
     * as an argument (push).
     *
     * @param mediator the new mediator
     */
    
	public void colleagueChanged(Colleague colleague);
}