package examples.prototype.aspectj;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.pattern.
 *
 * Contributor(s):   
 */

import ca.ubc.cs.spl.pattern.library.PrototypeProtocol;

/**
 * Implements the abstract Prototype design pattern. It attaches a default
 * <code>clone()</code> method on all <i>Prototype</i> participants and
 * provides a static <code>cloneObject(Prototype)</clone> method. The default
 * implementation of that method is to try to use the <code>clone()</code> 
 * method and, failing that, to call its protected <code>
 * createCloneFor(Prototype)</code> method. Concrete subaspects can either 
 * overwrite none or one (or both) of the methods to create individual 
 * results
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 05/13/02
 */ 
 
public aspect StringPrototypes extends PrototypeProtocol { 

    /**
     * Assigns the <code>Prototype</code> role to </code>MyString</code>
     */
    
    declare parents: MyString      implements Prototype;

    /**
     * Assigns the <code>Prototype</code> role to </code>AnotherString</code>
     */

    declare parents: AnotherString implements Prototype;

    /**
     * Provides an alternative method for cases when the default
     * <code>clone()</code> method fails: Clones objects "by hand".
     * 
     * @param object the prototype object to clone
     * @returns a copy of the object
     */

    protected Object createCloneFor(Prototype object) {
        if (object instanceof AnotherString) {
            return new AnotherString( ((AnotherString) object).toString());
        } else {
            return null;
        }
    } 

}